==> helpdesk.selectransportation.com_BCK%2001.12.2026.zip: helpdesk.selectransportation.com/config.php <==
<?php

// CONFIG - COMPANY (BRANCH) AND DEPARTMENT EMAILS SENT TO VP FOR APPROVAL
return [
'1 - HOUSTON FREIGHTLINER & WESTERN STAR' => [
      'ADMIN'                           => 'john.thomas@selectransportation.com',
      'BODY SHOP'                       => 'wally.melia@selectransportation.com',
      'MAIN SHOP'                       => 'charles.stewart@selectransportation.com',
      'MOBILE SERVICE'                  => 'charles.stewart@selectransportation.com',
      'NEW TRUCK SALES'                 => 'peter.gunderson@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
      'PARTS SALES DART BUILDING'       => 'bill.simko@selectransportation.com',
      'PARTS SALES TRAINING'            => 'bill.simko@selectransportation.com',
      'SERVICE SALES DART BUILDING'     => 'charles.stewart@selectransportation.com',
],

'2 - HOUSTON DISCOUNT TRUCK PARTS'  => [
      'ADMIN'                           => 'john.thomas@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
      'RECONDITIONING'                  => 'charles.stewart@selectransportation.com',
      'RECONDITIONING BODY SHOP'        => 'wally.melia@selectransportation.com',
],

'3 - CORPUS CHRISTI FREIGHTLINER & WESTERN STAR' => [
      'ADMIN'                           => 'jason.graham@corpuschristifreightliner.com',
      'BODY SHOP'                       => 'wally.melia@selectransportation.com',
      'MAIN SHOP'                       => 'charles.stewart@selectransportation.com',
      'MOBILE SERVICE CORPUS'           => 'charles.stewart@selectransportation.com',
      'NEW TRUCK SALES'                 => 'peter.gunderson@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
      'USED TRUCK SALES'                => 'ken.dominique@selectransportation.com',
],

'4 - BEAUMONT FREIGHTLINER & WESTERN STAR' => [
      'ADMIN'                           => 'chris.newton@beaumontfreightliner.com',
      'BODY SHOP'                       => 'wally.melia@selectransportation.com',
      'MAIN SHOP'                       => 'charles.stewart@selectransportation.com',
      'MOBILE SERVICE BEAUMONT'         => 'charles.stewart@selectransportation.com',
      'NEW TRUCK SALES'                 => 'peter.gunderson@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
      'USED TRUCK SALES'                => 'ken.dominique@selectransportation.com',
],

'5 - THOMAS BUS GULF COAST' => [
      'ADMIN'                           => 'john.thomas@selectransportation.com',
      'MAIN SHOP'                       => 'charles.stewart@selectransportation.com',
      'MOBILE SERVICE THOMAS'           => 'charles.stewart@selectransportation.com',
      'NEW TRUCK SALES'                 => 'peter.gunderson@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
],

'8 - SELECTRANSPORTATION RESOURCES, LLC' => [
      'ACCOUNTING'                      => 'john.thomas@selectransportation.com',
      'ADMIN'                           => 'john.thomas@selectransportation.com',
      'EXECUTIVE'                       => 'john.thomas@selectransportation.com',
      'HOSPITALITY & FOOD SERVICE'      => 'john.thomas@selectransportation.com',
      'INFORMATION TECHNOLOGY'          => 'john.thomas@selectransportation.com',
      'LEGAL'                           => 'john.thomas@selectransportation.com',
      'MAINTENANCE'                     => 'john.thomas@selectransportation.com',
      'STR PRODUCTIONS'                 => 'john.thomas@selectransportation.com',
      'TRAINING'                        => 'charles.stewart@selectransportation.com',
      'WARRANTY'                        => 'charles.stewart@selectransportation.com',
],

'9 - SELECSOFTWARE, LLC' => [
      'ADMIN'                           => 'john.thomas@selectransportation.com',
      'PARTS'                           => 'bill.simko@selectransportation.com',
],

'12 - SELECTRUCKS OF HOUSTON, LLC' => [
      'USED TRUCK SALES'                => 'ken.dominique@selectransportation.com',
],

'13 - SELECTRUCKS OF HOUSTON WHOLESALE, LLC' => [
      'USED TRUCK SALES'                => 'ken.dominique@selectransportation.com',
],

'14 - HFI INTERNET SALES' => [
      'ADMIN'                           => 'bill.simko@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
],


'15 - BROOKSHIRE FREIGHTLINER & WESTERN STAR' => [
      'ADMIN'                           => 'bill.simko@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
],

'24 - VICTORIA FREIGHTLINER & WESTERN STAR' => [
      'ADMIN'                           => 'john.thomas@selectransportation.com',
      'MAIN SHOP'                       => 'charles.stewart@selectransportation.com',
      'NEW TRUCK SALES'                 => 'peter.gunderson@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
      'USED TRUCK SALES'                => 'ken.dominique@selectransportation.com',
],

'25 - TALKE BTC' => [
      'ADMIN'                           => 'charles.stewart@selectransportation.com',
      'MAIN SHOP'                       => 'charles.stewart@selectransportation.com',
      'MOBILE SERVICE TALKEBTC'         => 'charles.stewart@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
],

'26 - LUFKIN FREIGHTLINER-WESTERN STAR' => [
      'ADMIN'                           => 'bill.simko@selectransportation.com',
      'MAIN SHOP'                       => 'charles.stewart@selectransportation.com',
      'MOBILE SERVICE'                  => 'charles.stewart@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',

],

'27 - SELECLEASE' => [
      'ADMIN'                           => 'john.thomas@selectransportation.com',
      'CONTRACT MAINTENANCE'            => 'john.thomas@selectransportation.com',
      'LEASING OPERATIONS'              => 'john.thomas@selectransportation.com',
      'MAIN SHOP SELECLEASE'            => 'charles.stewart@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
      'RENTAL OPERATIONS'               => 'john.thomas@selectransportation.com',
      'RETAIL OPERATIONS'               => 'john.thomas@selectransportation.com',
],

'28 - HOUSTON FREIGHTLINER WEST' => [
      'ADMIN'                           => 'bill.simko@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
],

'29 - HOUSTON FREIGHTLINER NORTH' => [
      'ADMIN'                           => 'bill.simko@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
],

'30 - SELECTECHNICAL INSTITUTE' => [
      'ADMIN'                           => 'john.thomas@selectransportation.com',
      'EDUCATION & TRAINING'            => 'john.thomas@selectransportation.com',
],


// CHANGE FORM WITHOUT PAY SELECTED -  EMAIL SENT TO HR + MANAGER addresses ELSE built-in fallbacks
'HR' => 'HRPan@strhouston.com',
// 'IT' => ['ITPan@strhouston.com', 'support@strhelpdesk.zendesk.com'],

// 'HR' => 'Saquib.patwa@selectransportation.com',
// 'IT' => 'Saquib.WebTest@selectransportation.com',

'default' => 'john.thomas@selectransportation.com',

];



?>

==> helpdesk.selectransportation.com_BCK%2010.14.2025.zip: helpdesk.selectransportation.com/config.php <==
<?php

// CONFIG - COMPANY (BRANCH) AND DEPARTMENT EMAILS SENT TO VP FOR APPROVAL
return [
'1 - HOUSTON FREIGHTLINER & WESTERN STAR' => [
      'ADMIN'                           => 'john.thomas@selectransportation.com',
      'BODY SHOP'                       => 'wally.melia@selectransportation.com',
      'MAIN SHOP'                       => 'charles.stewart@selectransportation.com',
      'MOBILE SERVICE'                  => 'charles.stewart@selectransportation.com',
      'NEW TRUCK SALES'                 => 'peter.gunderson@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
      'PARTS SALES DART BUILDING'       => 'bill.simko@selectransportation.com',
      'PARTS SALES TRAINING'            => 'bill.simko@selectransportation.com',
      'SERVICE SALES DART BUILDING'     => 'charles.stewart@selectransportation.com',
],

'2 - HOUSTON DISCOUNT TRUCK PARTS'  => [
      'ADMIN'                           => 'john.thomas@selectransportation.com',
      'HOUSTON DISCOUNT TRUCK PARTS'    => 'bill.simko@selectransportation.com',
      'RECONDITIONING'                  => 'charles.stewart@selectransportation.com',
      'RECONDITIONING BODY SHOP'        => 'wally.melia@selectransportation.com',
],

'3 - CORPUS CHRISTI FREIGHTLINER & WESTERN STAR' => [
      'ADMIN'                           => 'jason.graham@corpuschristifreightliner.com',
      'BODY SHOP'                       => 'wally.melia@selectransportation.com',
      'MAIN SHOP'                       => 'charles.stewart@selectransportation.com',
      'MOBILE SERVICE CORPUS'           => 'charles.stewart@selectransportation.com',
      'NEW TRUCK SALES'                 => 'peter.gunderson@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
      'USED TRUCK SALES'                => 'ken.dominique@selectransportation.com',
],

'4 - BEAUMONT FREIGHTLINER & WESTERN STAR' => [
      'ADMIN'                           => 'chris.newton@beaumontfreightliner.com',
      'BODY SHOP'                       => 'wally.melia@selectransportation.com',
      'MAIN SHOP'                       => 'charles.stewart@selectransportation.com',
      'MOBILE SERVICE BEAUMONT'         => 'charles.stewart@selectransportation.com',
      'NEW TRUCK SALES'                 => 'peter.gunderson@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
      'USED TRUCK SALES'                => 'ken.dominique@selectransportation.com',
],

'5 - THOMAS BUS GULF COAST' => [
      'ADMIN'                           => 'john.thomas@selectransportation.com',
      'MAIN SHOP'                       => 'charles.stewart@selectransportation.com',
      'MOBILE SERVICE THOMAS'           => 'charles.stewart@selectransportation.com',
      'NEW TRUCK SALES'                 => 'peter.gunderson@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
],

'8 - SELECTRANSPORTATION RESOURCES, LLC' => [
      'ACCOUNTING'                      => 'john.thomas@selectransportation.com',
      'ADMIN'                           => 'john.thomas@selectransportation.com',
      'EXECUTIVE'                       => 'john.thomas@selectransportation.com',
      'HOSPITALITY & FOOD SERVICE'      => 'john.thomas@selectransportation.com',
      'INFORMATION TECHNOLOGY'          => 'john.thomas@selectransportation.com',
      'LEGAL'                           => 'john.thomas@selectransportation.com',
      'MAINTENANCE'                     => 'john.thomas@selectransportation.com',
      'STR PRODUCTIONS'                 => 'john.thomas@selectransportation.com',
      'TRAINING'                        => 'charles.stewart@selectransportation.com',
      'WARRANTY'                        => 'charles.stewart@selectransportation.com',
],

'9 - SELECSOFTWARE, LLC' => [
      'ADMIN'                           => 'john.thomas@selectransportation.com',
      'PARTS'                           => 'bill.simko@selectransportation.com',
],

'12 - SELECTRUCKS OF HOUSTON, LLC' => [
      'USED TRUCK SALES'                => 'ken.dominique@selectransportation.com',
],

'13 - SELECTRUCKS OF HOUSTON WHOLESALE, LLC' => [
      'USED TRUCK SALES'                => 'ken.dominique@selectransportation.com',
],

'14 - HFI INTERNET SALES' => [
      'ADMIN'                           => 'bill.simko@selectransportation.com',
      'PARTS'                           => 'bill.simko@selectransportation.com',
],

'24 - VICTORIA FREIGHTLINER & WESTERN STAR' => [
      'ADMIN'                           => 'john.thomas@selectransportation.com',
      'MAIN SHOP'                       => 'charles.stewart@selectransportation.com',
      'MOBILE SERVICE VICTORIA'         => 'charles.stewart@selectransportation.com',
      'NEW TRUCK SALES'                 => 'peter.gunderson@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
      'USED TRUCK SALES'                => 'ken.dominique@selectransportation.com',
],

'25 - TALKE BTC' => [
      'ADMIN'                           => 'charles.stewart@selectransportation.com',
      'MAIN SHOP'                       => 'charles.stewart@selectransportation.com',
      'MOBILE SERVICE TALKEBTC'         => 'charles.stewart@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
],

'26 - LUFKIN FREIGHTLINER-WESTERN STAR' => [
      'ADMIN'                           => 'bill.simko@selectransportation.com',
      'LUFKIN FREIGHTLINER'             => 'bill.simko@selectransportation.com',
],

'27 - SELECLEASE' => [
      'ADMIN'                           => 'john.thomas@selectransportation.com',
      'CONTRACT MAINTENANCE'            => 'john.thomas@selectransportation.com',
      'LEASING OPERATIONS'              => 'john.thomas@selectransportation.com',
      'MAIN SHOP SELECLEASE'            => 'charles.stewart@selectransportation.com',
      'MOBILE SERVICE SELECLEASE'       => 'charles.stewart@selectransportation.com',
      'PARTS SALES'                     => 'bill.simko@selectransportation.com',
      'RENTAL OPERATIONS'               => 'john.thomas@selectransportation.com',
      'RETAIL OPERATIONS'               => 'john.thomas@selectransportation.com',
],

'28 - HOUSTON FREIGHTLINER WEST' => [
      'ADMIN'                           => 'bill.simko@selectransportation.com',
      'HOUSTON FREIGHTLINER WEST'       => 'bill.simko@selectransportation.com',
],

'29 - HOUSTON FREIGHTLINER NORTH' => [
      'ADMIN'                           => 'bill.simko@selectransportation.com',
      'HOUSTON FREIGHTLINER NORTH'      => 'bill.simko@selectransportation.com',
],

'30 - SELECTECHNICAL INSTITUTE' => [
      'ADMIN'                           => 'john.thomas@selectransportation.com',
      'EDUCATION & TRAINING'            => 'john.thomas@selectransportation.com',
],

'default' => 'john.thomas@selectransportation.com',

];



?>
